@@ -544,7 +544,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
         self._accEventNameChanged, 
         'object:property-change:accessible-name')
 
-    self.action_group = gtk.ActionGroup('TreeActions')
+    self.action_group = gtk.ActionGroup.new('TreeActions')
     self.action_group.add_toggle_actions(
       [('HideShowLeaves', None, _('_Hide/Show Applications without children'), None,
         None, self._onHideShowLeaves, False)])
